from setuptools import setup


setup(
    name='ec2-enc-check',
    version='1.2',
    url='https://github.com/Kyle1668/AWS-Ec2-Volumes-Encryption-Check/tree/package',
    author='Kyle O\'Brien',
    author_email='kyledevinobrien1@gmail.com',
    scripts=['ec2-enc-check.py'],
)
